// Optional: Enable globe lighting for a more realistic appearance.
// viewer.scene.globe.enableLighting = true;

// Set up an event handler for left-clicks on the globe.
viewer.screenSpaceEventHandler.setInputAction(function (click) {
    // Convert the 2D click position to a 3D Cartesian coordinate on the globe.
    const cartesian = viewer.camera.pickEllipsoid(click.position);
    if (cartesian) {
        // Convert the Cartesian coordinate to geographic coordinates.
        const cartographic = Cesium.Cartographic.fromCartesian(cartesian);
        const longitude = Cesium.Math.toDegrees(cartographic.longitude);
        const latitude = Cesium.Math.toDegrees(cartographic.latitude);

        // Prompt the user for an annotation.
        const note = prompt('Note for this location:');
        if (note && note.trim() !== "") {
            const entity = viewer.entities.add({
                position: Cesium.Cartesian3.fromDegrees(longitude, latitude),
                point: {
                    pixelSize: 5,
                    color: Cesium.Color.WHITE
                },
                label: {
                    text: note,
                    font: '18px sans-serif',
                    fillColor: Cesium.Color.YELLOW,
                    outlineColor: Cesium.Color.BLACK,
                    outlineWidth: 2,
                    style: Cesium.LabelStyle.FILL_AND_OUTLINE,
                    verticalOrigin: Cesium.VerticalOrigin.BOTTOM,
                    pixelOffset: new Cesium.Cartesian2(0, -5)
                }
            });
            // console.log("Entity added:", entity);
        } else {
            console.log("No valid note entered.");
        }
    } else {
        console.log("Clicked outside the ellipsoid.");
    }
}, Cesium.ScreenSpaceEventType.LEFT_CLICK);
